@@ -19,6 +19,10 @@ from .item2vec import Item2Vec
 from .deepwalk import DeepWalk
 from .ngcf import NGCF
 from .lightgcn import LightGCN
+from .pinsage import PinSage
+from .pinsage_dgl import PinSageDGL
+from .graphsage import GraphSage
+from .graphsage_dgl import GraphSageDGL
 
 __all__ = [
     "UserCF",
@@ -42,4 +46,8 @@ __all__ = [
     "DeepWalk",
     "NGCF",
     "LightGCN",
+    "PinSage",
+    "PinSageDGL",
+    "GraphSage",
+    "GraphSageDGL",
 ]
