@@ -11,7 +11,7 @@ author: massquantity
 """
 from tensorflow.keras.initializers import truncated_normal as tf_truncated_normal
 
-from ..bases import TfBase
+from ..bases import ModelMeta, TfBase
 from ..tfops import (
     dropout_config,
     multi_sparse_combine_embedding,
@@ -32,7 +32,7 @@ from ..utils.validate import (
 )
 
 
-class FM(TfBase):
+class FM(TfBase, metaclass=ModelMeta):
     """
     Note this implementation is actually a mixture of FM and NFM,
     since it uses one dense layer in the final output
@@ -50,8 +50,9 @@ class FM(TfBase):
         loss_type="cross_entropy",
         embed_size=16,
         n_epochs=20,
-        lr=0.01,
+        lr=0.001,
         lr_decay=False,
+        epsilon=1e-5,
         reg=None,
         batch_size=256,
         num_neg=1,
@@ -97,6 +98,7 @@ class FM(TfBase):
                 n_epochs,
                 lr,
                 lr_decay,
+                epsilon,
                 batch_size,
                 num_neg,
                 k,
@@ -130,9 +132,8 @@ class FM(TfBase):
         # For original FM, just add K dim together:
         # pairwise_term = 0.5 * tf.reduce_sum(pairwise_term, axis=1)
         if self.use_bn:
-            pairwise_term = tf.layers.batch_normalization(
-                pairwise_term, training=self.is_training
-            )
+            batch_norm = tf.keras.layers.BatchNormalization()
+            pairwise_term = batch_norm(pairwise_term, training=self.is_training)
         pairwise_term = tf_dense(units=1, activation=tf.nn.elu)(pairwise_term)
         self.output = tf.squeeze(tf.add(linear_term, pairwise_term))
         count_params()
