@@ -1,11 +1,13 @@
 from .base import Base
 from .embed_base import EmbedBase
+from .gensim_base import GensimBase
+from .meta import ModelMeta
 from .tf_base import TfBase
-from .tf_mixin import TfMixin
 
 __all__ = [
     "Base",
     "EmbedBase",
+    "GensimBase",
+    "ModelMeta",
     "TfBase",
-    "TfMixin",
 ]
