@@ -68,7 +68,9 @@ class DataInfo(object):
         self._id2item = None
         self._data_size = None
         self.popular_items = None
-        # store old sparse len and oov
+        # store old info for rebuild models
+        self.old_n_users = None
+        self.old_n_items = None
         self.old_sparse_len = None
         self.old_sparse_oov = None
         self.old_sparse_offset = None
@@ -98,7 +100,7 @@ class DataInfo(object):
 
     @property
     def sparse_col(self):
-        if not self.col_name_mapping["sparse_col"]:
+        if not self.col_name_mapping or not self.col_name_mapping["sparse_col"]:
             return EmptyFeature
         return Feature(
             name=list(self.col_name_mapping["sparse_col"].keys()),
@@ -107,7 +109,7 @@ class DataInfo(object):
 
     @property
     def dense_col(self):
-        if not self.col_name_mapping["dense_col"]:
+        if not self.col_name_mapping or not self.col_name_mapping["dense_col"]:
             return EmptyFeature
         return Feature(
             name=list(self.col_name_mapping["dense_col"].keys()),
@@ -116,7 +118,7 @@ class DataInfo(object):
 
     @property
     def user_sparse_col(self):
-        if not self.col_name_mapping["user_sparse_col"]:
+        if not self.col_name_mapping or not self.col_name_mapping["user_sparse_col"]:
             return EmptyFeature
         return Feature(
             name=list(self.col_name_mapping["user_sparse_col"].keys()),
@@ -125,7 +127,7 @@ class DataInfo(object):
 
     @property
     def user_dense_col(self):
-        if not self.col_name_mapping["user_dense_col"]:
+        if not self.col_name_mapping or not self.col_name_mapping["user_dense_col"]:
             return EmptyFeature
         return Feature(
             name=list(self.col_name_mapping["user_dense_col"].keys()),
@@ -134,7 +136,7 @@ class DataInfo(object):
 
     @property
     def item_sparse_col(self):
-        if not self.col_name_mapping["item_sparse_col"]:
+        if not self.col_name_mapping or not self.col_name_mapping["item_sparse_col"]:
             return EmptyFeature
         return Feature(
             name=list(self.col_name_mapping["item_sparse_col"].keys()),
@@ -143,7 +145,7 @@ class DataInfo(object):
 
     @property
     def item_dense_col(self):
-        if not self.col_name_mapping["item_dense_col"]:
+        if not self.col_name_mapping or not self.col_name_mapping["item_dense_col"]:
             return EmptyFeature
         return Feature(
             name=list(self.col_name_mapping["item_dense_col"].keys()),
@@ -152,6 +154,8 @@ class DataInfo(object):
 
     @property
     def user_col(self):
+        if not self.col_name_mapping:
+            return []
         # will be sorted by key
         return (
             self.col_name_mapping["user_sparse_col"]
@@ -161,6 +165,8 @@ class DataInfo(object):
 
     @property
     def item_col(self):
+        if not self.col_name_mapping:
+            return []
         # will be sorted by key
         return (
             self.col_name_mapping["item_sparse_col"]
@@ -252,6 +258,8 @@ class DataInfo(object):
         self._data_size = None
 
     def store_old_info(self):
+        self.old_n_users = self.n_users
+        self.old_n_items = self.n_items
         if (
             self.sparse_unique_vals is not None
             or self.multi_sparse_unique_vals is not None
@@ -281,14 +289,14 @@ class DataInfo(object):
                     main_name = self.col_name_mapping["multi_sparse"][col]
                     pos = self.sparse_col.name.index(main_name)
                     # multi_sparse case, second to last is redundant.
-                    # Used in base.py, rebuild_graph()
+                    # Used in rebuild_tf_model(), rebuild_torch_model()
                     self.old_sparse_len.append(-1)
                     # self.old_sparse_oov.append(self.sparse_oov[pos])
                     self.old_sparse_offset.append(self.sparse_offset[pos])
 
     def expand_sparse_unique_vals_and_matrix(self, data):
-        self.reset_property()
         self.store_old_info()
+        self.reset_property()
 
         user_diff = np.setdiff1d(data.user.to_numpy(), self.user_unique_vals)
         if len(user_diff) > 0:
