@@ -1,7 +1,8 @@
-from .configs import dropout_config, lr_decay_config, reg_config
+from .configs import dropout_config, lr_decay_config, reg_config, sess_config
 from .features import get_feed_dict, multi_sparse_combine_embedding
-from .layers import dense_nn, conv_nn, max_pool, tf_dense
+from .layers import dense_nn, conv_nn, max_pool, tf_rnn, tf_dense
 from .loss import choose_tf_loss
+from .rebuild import rebuild_tf_model
 from .variables import modify_variable_names, var_list_by_name
 from .version import tf, TF_VERSION
 
@@ -10,11 +11,14 @@ __all__ = [
     "dropout_config",
     "lr_decay_config",
     "reg_config",
+    "sess_config",
     "get_feed_dict",
     "multi_sparse_combine_embedding",
     "dense_nn",
     "conv_nn",
     "max_pool",
+    "rebuild_tf_model",
+    "tf_rnn",
     "tf_dense",
     "choose_tf_loss",
     "modify_variable_names",
