@@ -5,11 +5,15 @@ from .tf_trainer import (
     WideDeepTrainer,
     YoutubeRetrievalTrainer,
 )
+from .torch_trainer import SageDGLTrainer, SageTrainer, TorchTrainer
 
 __all__ = [
     "BPRTrainer",
     "RNN4RecTrainer",
+    "SageDGLTrainer",
+    "SageTrainer",
     "TensorFlowTrainer",
+    "TorchTrainer",
     "WideDeepTrainer",
     "YoutubeRetrievalTrainer",
 ]
